/*
 * 按钮组件抽象类
 * Btn描述:
 *     简单矩形元素/可点击
 * 触发BTN_CLICK事件
*/
define(['Widget'],function(require, exports){
	$.widget("ys.Btn",$.ys.Widget,{
		enable:true, //可点击状态
		//默认参数
		//初始化，控件生命周期内只运行一次
		_init: function () {
			this._super();
			this.element.attr("enable","true");
			if(this.options.height){
				this.setLineHeight(this.options.height);
			}
			this.element.css("cursor","pointer");
			if(this.options.borderRadius){
				this.element.css("border-radius",this.options.borderRadius);
			}

			//事件兼容 mousedown -> mouseup -> click   touchstart -> touchmove -> touchend
			if(!this.options.hideTouchAnimate ){
				this.element.bind("touchstart",this,this.mousedownClick);
				this.element.bind("touchend",this,this.mouseupClick);
			}
			this.element.bind("click",this,this.onClick);
			this.element.attr("tapmode")
			this.element.bind("touchend",this,this.onClick);
		},
		onClick:function(e){
			e.stopPropagation();
            e.preventDefault();
			
			if(e.data.enable){
				e.data.element.trigger("BTN_CLICK");
				//console.log("事件抛出");
				e.data.setLock();
			}
		},
		mousedownClick:function(e){
			var _this = e.data;
			if(_this.enable){
				_this.element.css({"opacity":0.5});
			}
		},
		mouseupClick:function(e){
			var _this = e.data;
			if(_this.enable) {
				_this.element.css({"opacity":1});
			}
		},
		/**设置按钮不可点击 */
		setDisable:function () {
			this.enable = false;
			//alert("22");
			this.element.css({"opacity":0.5});
		},
		/**设置按钮可点击 */
		setEnable:function () {
			this.enable = true;
			//alert("11");
			this.element.css({"opacity":1});
		},
		getStatus:function(){
			return this.enable;
		},
		setUnlock:function(){
			this.enable = true;
		},
		setLock:function(){
			//console.log("自锁");
			var that = this;
			this.enable = false;
			setTimeout(function(){
				//console.log("解锁");
				if(!that.options.noNeedAutoUnlock){
					that.setUnlock();
				}
			},500);
		},
		addElement:function(data){
			this.element.append(data);
		},
		//创建控件，控件生命周期内会运行多次
		_create: function () {},
		// 释放控件
		destroy: function () {
			$.Widget.prototype.destroy.call(this);
		}
	});
})
