/*
 * 输入框组件抽象类
*/
define(['Widget','style'],function(require, exports){
    $.widget("ys.Input",$.ys.Widget,{
        //默认参数
		_input:null,
		_label:null,
		_isFocus:false,
        //初始化，控件生命周期内只运行一次
        _init: function () {   
			this._super();
			this.element.css("position","relative");
			this._input = $('<input type="text" />');
			this._input.css({"background-color":"transparent","outline":"none",'vertical-align': 'middle'});
			this._input.style({height:this.options.height,lineHeight:this.options.height,width:this.options.width,});
			if(this.options.fontSize){
				this._input.style({fontSize:this.options.fontSize});
			}
			//this._input.attr("placeholder",this.options.placeholder)
			if(this.options.maxLen){
				this.setMaxLen(this.options.maxLen);
			}
			
			this._input.appendTo(this.element);
			//this._input.bind("change",this,this._onChange);
			this._input.bind('keydown',this,this._onKeyDown);
			this._input.bind("keyup",this,this._onKeypress);
            var that = this;
			this._input.bind("focus",function(){
				that._isFocus = true;
			})
			this._input.bind("blur",function(){
				that._isFocus = false
				that.element.trigger("INPUT_BLUR_TAR");
			})
			

			this._label = $("<div class='placeholder'></div>");
			this._label.style({"color":"#c8c8c8","font-size":this.options.fontSize,"height":this.options.height,
		"line-height":this.options.height,"width":this.options.width,"position":"absolute","top":0,"left":0,"pointer-events":"none"})
			if(navigator.userAgent.indexOf('Android')>-1){
				this._label.style({"top":"2px",});//兼容安卓
			}
			this.element.append(this._label)
			this._label.html(this.options.placeholder)

			if(this.options.text|| this._input.val()){
				this._input.val(this.options.text);
				this._label.hide();
			}
			//this.element.trigger("LABEL_CHANGE",1);
			
			if(this.options.changeOnce === true){//改变只通知一次
				this._timer = setInterval(function(obj){
					obj._onInputChangeOnce();
				},100,this);
			}else{
				this._timer = setInterval(function(obj){
					obj._onInputChange();
				},100,this);
			}
			this._input.bind("click",function(){
				var str = $(this).val();
				$(this).val("");
				$(this).val(str).focus();
			});
		},
		setPlaceHolder:function (text) {
			this._label.html(text)
		},
		setType:function(type){
			this._input.attr("type",type);
		},
		_onKeyDown:function(e){
			var key = e.which;
			if (key == 13) {
				
				e.data._input.blur();
				e.data.element.trigger("TEXT_CHANGE");
				e.data.element.trigger("INPUT_SURE");
			}
		},
		
		_onKeypress:function(e){
			var keycode = e.keyCode;
			//alert(keycode)
                if(keycode=='13') {
                    e.preventDefault();  
					//请求搜索接口
					e.data.element.trigger("INPUT_SURE");
                    
                }
		},
		setMaxLen:function(len){
			this._input.attr("maxlength",len);
		},
		_onChange:function(e){
			e.data.element.trigger("TEXT_CHANGE");
			var value = e.data._input.val();
			if(value == ''){
				e.data._label.show();
				e.data.element.trigger("LABEL_CHANGE",1);
			}else{
				e.data._label.hide();
				e.data.element.trigger("LABEL_CHANGE",0);
				
			}
			
		},
		inputBlur:function(){
			this._input.blur();
		},
		setValue:function(val){
			this._input.val(val);
		},
		getValue:function(){
            return this._input.val();
        },
		clearText:function(){
            this._input.val('');
		},
		setFocus:function(){
            this._input.focus()
		},
		setBlur:function(){
            this._input.blur()
		},
		_onInputChange:function(){
			var value = this._input.val();
			if(value == ''){
				this._label.show();
				this.element.trigger("LABEL_CHANGE",1);
			}else{
				this._label.hide();
				this.element.trigger("LABEL_CHANGE",0);
			}
		},
		_lastValue:'',
		_onInputChangeOnce:function(){
			var value = this._input.val();
			if(value === this._lastValue){
				return
			}
			if(value == ''){
				this._label.show();
				this.element.trigger("LABEL_CHANGE",1);
			}else{
				this._label.hide();
				this.element.trigger("LABEL_CHANGE",0);
			}
			this._lastValue = value;
		},
		getFocus:function(){
			//return this._input.is(':focus');
			return this._isFocus;
		},
		
        //创建控件，控件生命周期内会运行多次
        _create: function () {},
        // 释放控件
        destroy: function () {
            $.Widget.prototype.destroy.call(this);
        }
    });
});  

