/*
 * Widget 鹰硕组件抽象类  
 * 设置 盒子模型宽高/内外边距/定位/行高
 * 通用字体样式/字体大小 
 * _htmlSize 动态计算根元素的大小    
 * setPxSize 设置盒子模型尺寸方法  
 *      1、直接传 rem  
 *      2、将px转rem   size.replace("px","")/(window.innerWidth/16)  
 * @Author Zhang       
 * @Date 2019/01/15    
 *   
*/
define(['jquery','jqueryui',],function($){  
	$.widget("ys.Widget", {  
		//默认参数 
		FONT_DEFAULT_FAMILY:"'Microsoft YaHei', 'Helvetica', 'Arial', 'Verdana', 'sans-serif'",   
		FONT_COLOR_C1:"#333",
		FONT_COLOR_C2:"#666", 
		FONT_COLOR_C3:"#999",
		FONT_COLOR_HOVER:"#F20d0d",
		TEXT_ALIGN_CENTER:"center",     
		_htmlSize:1, //默认为 1 
		_DESIGN_SIZE:375, //设计尺寸基准 375
		s:0,

		/**
		 * 屏幕宽度
		 */
		winW:window.innerWidth,
		
		//初始化，控件生命周期内只运行一次
		_init: function () {  
			//图片倍数 
			if(!this.ImgX){
				this.ImgX = Math.ceil( window.devicePixelRatio*window.innerWidth/this._DESIGN_SIZE );
			}
			this.s = 1/16
			if(this.options.textAlign){
				this.css("text-align",this.options.textAlign);
			}
			//设置行高/宽/高 
			if(this.options.lineHeight){ 
                this.setLineHeight(this.options.lineHeight); 
			}
			if(this.options.minHeight){
				this.setMinHeight(this.options.minHeight); 
			}
		    if(this.options.minWidth){  
                this.setMinWidth(this.options.minWidth);
            }
			if(this.options.height){
				this.setHeight(this.options.height); 
            }
			if(this.options.width){
				this.setWidth(this.options.width);
			}			
			//设置外边距
			if(this.options.marginTop){ 
				this.setMarginTop(this.options.marginTop);  
			}
            if(this.options.marginRight){
                this.setMarginRight(this.options.marginRight); 
			}
			if(this.options.marginBottom){ 
				this.setMarginBottom(this.options.marginBottom);
            }
            if(this.options.marginLeft){
                this.setMarginLeft(this.options.marginLeft); 
            }
           
			//设置内边距
            if(this.options.paddingTop){ 
				this.setPaddingTop(this.options.paddingTop);
			}
			if(this.options.paddingRight){
                this.setPaddingRight(this.options.paddingRight);   
            }   
            if(this.options.paddingBottom){   
				this.setPaddingBottom(this.options.paddingBottom); 
			}
			if(this.options.paddingLeft){
                this.setPaddingLeft(this.options.paddingLeft); 
            }
			//解析皮肤
			this.parseSkin();
		},
		parseSkin:function(){
			if(this.element.attr("ysSkinBgColor")){
				//this.element.css("background-color",global.ysSkin.bgColor[this.element.attr("ysSkinBgColor")]);
			}
		},
		_create: function () {}, 
		//设置盒子宽高 
		setHeight:function(size){
			if(this.setPxSize(size) < this.options.minHeight){
				this.element.css("height",this.options.minHeight);
			}else{
				this.element.css("height",this.setPxSize(size));
			}
		},
		setWidth:function(size){
			if(this.setPxSize(size) < this.options.minWidth){
				this.element.css("width",this.options.minWidth);
			}else{
				this.element.css("width",this.setPxSize(size));
			}
            
		},
		setLineHeight:function(size){ 
            this.element.css("line-height",this.setPxSize(size));
		},
        setMinHeight:function(size){
            this.element.css("min-height",size);
        },
        setMinWidth:function(size){
			this.set
            this.element.css("min-width",size);
		},

		//设置外边距
		setMarginTop:function(size){
            this.element.css("margin-top",this.setPxSize(size));
		},
		setMarginRight:function(size){  
            this.element.css("margin-right",this.setPxSize(size));
        },
		setMarginBottom:function(size){
            this.element.css("margin-bottom",this.setPxSize(size));
		},
        setMarginLeft:function(size){
            this.element.css("margin-left",this.setPxSize(size));
		},
		setPadding:function(size){  
			this.element.css("padding",this.setPxSize(size));
		},
		//设置内边距
		setPaddingTop:function(size){  
            this.element.css("padding-top",this.setPxSize(size));
		},
		setPaddingRight:function(size){
            this.element.css("padding-right",this.setPxSize(size));
		},
		setPaddingBottom:function(size){
            this.element.css("padding-bottom",this.setPxSize(size));
		},
		setPaddingLeft:function(size){
            this.element.css("padding-left",this.setPxSize(size));
        }, 
	
		//设置位置
		setTop:function(size){
			this.options.top = size;
            this.element.css("top",this.setPxSize(size));
		},
		getTop:function(){ 
			return this.element.css("top");
		},
		setLeft:function(size){
			this.options.left = size;
            this.element.css("left",this.setPxSize(size));
		},
        setRight:function(size){
			this.options.right = size;
            this.element.css("right",this.setPxSize(size));
        },
        setBottom:function(size){
			this.options.bottom = size;
            this.element.css("bottom",this.setPxSize(size));
		},
		
		/*
		 * 转换rem 
		 * 1、若是px 直接转 rem
		 * 2、直接单位rem 
         */ 
		setPxSize:function(size){     
            if(typeof size !== 'number' && typeof size !== 'string'){  
            	throw new Error("error param type: the param 'size' is "+typeof size);
            }
            if(typeof size === "string"){    
                if(size.replace("px","") != size){ // 若是 px 直接转  rem    
					return this._htmlSize*parseFloat(size.replace("px","")/16)+"rem";     
				}
				if(size.replace("rem","") != size){ //rem      
					return this._htmlSize*parseFloat(size.replace("rem",""))+"rem";
				}  
			}  
			return size; 
		},
		/**
		 * 根据UI设计稿获取设备实际px
		 * @param {int} num 设计稿px值
		 * @param {boolean} unit 是否需要单位
		 */
		getDevPx:function(num,unit){
			if(typeof num !== "number"){
				num = parseInt(num);
				if(isNaN(num)){
					throw new Error("error param type: the param 'size' is "+typeof num);
				}
			}
			return num/this._DESIGN_SIZE*this.winW + (unit ? 'px' : 0);
		},
		/**
		 * 设置css时，自动换算
		 * @returns {ys.Widget}
		 */
		css:function(){
			var that = this,css = arguments[0];
			switch (arguments.length) {
				case 1:{//只有1个参数时
					if(typeof css==="object"){//且该参数是一个对象
						for(var x in css){//遍历css对象
							var value = css[x];
							if(typeof value === 'string'){
								/**
								 * 正则匹配px,并重新计算设备实际px
								 */
								css[x] = value.replace(/[0-9]+px/,function (num) {
									return that.getDevPx(num,true);
								});
							}
						}
						this.element.css(css);
					}
					break;
				}
				case 2:{//只有2个参数时，此时是css 键值对
					var value = arguments[1];
					if(typeof value === 'string'){
						value = value.replace(/[0-9]+px/,function (num) {
							return that.getDevPx(num,true);
						});
					}
					this.element.css(css,value);
					break;
				}
			}
			
			return this;
		},
		/**
		 * 给指定元素，设置css时，自动换算
		 * @returns {ys.Widget}
		 */
		cssEle:function(){
			var that = this,
				element = arguments[0],
				css;
			switch (arguments.length) {
				case 2:{//只有1个参数时
					css = arguments[1];
					if(typeof css==="object"){//且该参数是一个对象
						for(var x in css){//遍历css对象
							var value = css[x];
							if(typeof value === 'string'){
								/**
								 * 正则匹配px,并重新计算设备实际px
								 */
								css[x] = value.replace(/[0-9]+px/,function (num) {
									return that.getDevPx(num,true);
								});
							}
						}
						element.css(css);
					}
					break;
				}
				case 3:{//只有2个参数时，此时是css 键值对
					var value = arguments[2];
					if(typeof value === 'string'){
						value = value.replace(/[0-9]+px/,function (num) {
							return that.getDevPx(num,true);
						});
					}
					css = arguments[1];
					element.css(css,value);
					break;
				}
			}
			return this;
		},
		/**
		 * 自动更改图片src倍数
		 * @param {string} src 
		 */
		autoSrc:function(src){
			if(typeof src==='string'){
			
				var x = this.ImgX;//正确的图片倍数
				return src.replace(/@[0-9]{1}x\.(png|jpg|gif)$/,function(matchStr,extention){
					if(x>3){//目前最大 只有3倍图
						x = 3;
					}
					if(x<2){//目前最小 只有2倍图
						x = 2;
					}
					return "@" + x + 'x.' + extention;
				});
			}
			return src;
		},
		addClear:function(){
			this.element.append("<div style='clear:both'></div>");
		},
		// 释放控件
		destroy: function () {
			$.Widget.prototype.destroy.call(this);
		}
	});
})