/**
 * APP全局配置
 */
define(['Shell','Config'],function(Shell,Config){
    var ApiConfig = {

        /**
         * 接口全局配置
         */
        api: {
            url: {//所有url**末尾**不要加斜杠
                base: "",
                app: "",
            },
            getBaseUrl:function() {
                return this.url.base;
            },
            /**
             * 获取app端接口uri
             * @param {string} path 相对路径，以“/”开始
             * @param {object}} data 暂时只支持一维对象
             * @param {boolean} addToken 是否添加token,默认添加，false不添加
             */
            get: function (path, data) {
                return this.url.app + this.makePath(path, data);
            },
             /**
             * 获取完整uri
             * @param {string} path 相对路径，以“/”开始 
             * @param {object}} data 暂时只支持一维对象
             * @param {boolean} addToken 是否添加token,默认添加，false不添加
             */
            getUrl:function (path, data) {
                return this.url.base + this.makePath(path, data);
            },
            /**
             * 根据路径获取连接符号，返回可能是 ? & ''
             * @param {string} path 
             */
            getConnectSymbol:function(path){
                return path.indexOf("?") > -1
                        ? (path.indexOf("&") > -1 && path.indexOf("&") < path.length - 1 ? '&' : '')
                        : '?'
            },
            getToken:function(){
                var token;
                try{
                    token = pageParam.token;
                }catch(e){
                    token = window.localStorage.getItem("accoutToken")
                    console.log('___lost pageParam.token!')
                }
                if(''==token){
                    console.log('___lost token!')
                    return '';
                }
                return token;
            },
            /**
             * 构造路径get参数
             * @param {string} path 相对路径，以“/”开始 
             * @param {object}} data 暂时只支持一维对象
             * @param {boolean} addToken 是否添加token,默认添加，false不添加
             */
            makePath:function (path, data) {
                var params = new URLSearchParams();
                // params.append('_time_', new Date().getTime());
                
         
                if (Object.prototype.toString.call(data) === "[object Object]") {
                    for (var x in data) {
                        params.append(x, data[x]);
                    }
                }
                var param = params.toString();
                return param ? (path + this.getConnectSymbol(path) + param) : path;
            },
            /**
             * 接口全局错误处理
             */
            errors: {
                error: function () {
                    // "timeout", "error", "abort", and "parsererror"
                },
                "Please login first": function (data) {
                    var logout = function(){
                        if(window.__logout__ === true){
                            return false;
                        }
                        window.__logout__ = true;
                        setTimeout(function(){
                            window.__logout__ = false;
                        },1000);
                        try{
                            api.toast({msg: '登录失效',duration: 2000,location: 'middle'});
                            setTimeout(function(){
                                Shell.sendEvent('backLogin',data);
                                window.localStorage.removeItem("password");//在浏览器存储密码
                                window.localStorage.removeItem("accoutToken");
                            },2000);
                        }catch(e){
                            console.log("退出登录时发生异常！！");
                            console.warn(e)
                        }
                    }
                    setTimeout(logout,typeof api === 'object' ? 0 : 300);
                }
            },
            successHook: function (data) {
                for (var key in this.successHandle) {
                    if (key in data) {
                        this.successHandle[key](data)//执行函数
                    }
                }
            },
            successHandle: {
                syn: function (data) {
                    console.log('____syn____')
                    var syn = data.syn,synHandle;
                    synHandle = {
                        userData:function(userData){
                            console.log('____userDataChange____:'+JSON.stringify(userData))
                            if(typeof userData === 'object'){
                                Config.updateUserInfo(userData);
                                Shell.sendEvent('userDataChange',userData);//告诉原生壳用户数据改变了
                            }
                            
                        },
                        has_new_message:function(has_new_message){
                            // console.log('____messageUpdateData____:'+JSON.stringify(has_new_message))
                            window.localStorage.setItem("messageUpdateData", JSON.stringify(has_new_message));//更新用户数据缓存
                            Shell.sendEvent('messageUpdateData',has_new_message)//告诉原生壳用户数据改变了
                        },
                        has_new_power:function(has_new_power){
                            //'department','org','no'
                            if(typeof has_new_power ==='string'){
                                switch (has_new_power){
                                    case 'yes'://兼容老版本，下次版本更新后可以移除
                                    case 'department':
                                        Shell.sendEvent('powerChange')//告诉原生壳，团队空间权限发送变化
                                        break;
                                    
                                    case 'org':
                                        Shell.sendEvent('powerChangeOrg')//告诉原生壳，组织空间权限发送变化
                                        break;
                                        
                                }
                            }
                        }
                    };
                    for (var key in synHandle) {
                        if (key in syn) {
                            synHandle[key](syn[key])//执行函数
                        }
                    }
                },
                res_version: function (data) {
                    Shell.sendEvent('zipFileChange',data.res_version)//告诉原生壳用户数据改变了
                },
            },
        },
    };
    
    return ApiConfig;
});