/**
 * APP全局配置
 */
define(['base64'],function(base64){
    var Config = {
        /**
         * 在网址获取数据
         * @param {string} name  查询字段名
         */
        getQueryString:function (name) { 
            var reg = new RegExp("(^|&)" + name + "=([^&]*)(&|$)", "i"); 
            var r = window.location.search.substr(1).match(reg); 
            if (r != null) return unescape(r[2]); 
            return null; 
        },
        /**
         * 初始化主页面的必需参数
         * @return {object} infoDic 返回用户信息userInfo
         */
        initPageParam:function(){
            // console.log("_________12345_____________"+window.location.search)
            var infoDic,infoStr;
            try {
                var infodata;
                window.localStorage.setItem("encrypt",this.getQueryString('encrypt')==1?'1':'');
                infodata = this.getQueryString("userInfo");//原生通过网址传过来的参数
                infoStr = base64.decode(infodata);
                infoData = void 0;
                if(infoStr){
                    try{
                        infoDic = JSON.parse(infoStr);
                    }catch(e){
                        throw new Error("parse userInfo Error");
                    }
                    window.localStorage.setItem("userInfo",JSON.stringify(infoDic));
                    
                }
                if(infoDic){
                    infoDic.org_id      && window.localStorage.setItem("org_id",infoDic.org_id);
                    infoDic.org_name    && window.localStorage.setItem("org_name",infoDic.org_name);
                    infoDic.urls        && window.localStorage.setItem("cloudUrls",JSON.stringify(infoDic.urls));
                    infoDic.token       && window.localStorage.setItem("accoutToken",infoDic.token);
                }
            } catch (e) {
                console.warn(e)
                //兼容老版本
                if(!infoDic){
                    infoDic = window.localStorage.getItem("userInfo");
                    try {
                        infoDic = JSON.parse(infoDic)
                    } catch (e) {
                        infoDic = void 0;
                    }
                }
                
            }
            if(!infoDic){
                // throw new Error('没有用户数据了')
            }
            return infoDic;
        },
        //更新用户数据
        updateUserInfo:function (userInfo) {
            var infoDic = window.localStorage.getItem("userInfo");
            try {
                infoDic = JSON.parse(infoDic)
            } catch (e) {
                infoDic = void 0;
            }
            console.log('infoDic_____________')
            if(infoDic){
                for(var key in userInfo){
                    if(key in infoDic){//如果数据在这个数据里才更新
                        if(infoDic[key] != userInfo[key]){
                            console.log('change:'+key+",compare:before"+infoDic[key]+",after:"+userInfo[key])
                            infoDic[key] = userInfo[key]
                        }
                    }
                }
                window.localStorage.setItem("userInfo",JSON.stringify(infoDic));
                infoDic.org_id      && window.localStorage.setItem("org_id",infoDic.org_id);
                infoDic.org_name    && window.localStorage.setItem("org_name",infoDic.org_name);
                infoDic.urls        && window.localStorage.setItem("cloudUrls",JSON.stringify(infoDic.urls));
                infoDic.token       && window.localStorage.setItem("accoutToken",infoDic.token);
                return infoDic;
            }
        },
        getThumb:function () {
            try {
                var config = {};
                config.url = global.urls.thumb_config;
                config.url = global.urls.type;
                config.switch = global.is_thumb_model === "yes"
                config.size = global.thumb_width_height_config;
                return config
            } catch (e) {

            }
            // var global = {
            //     "thumb_config":{
            //         "task":"https://commonpreview.ys100.com/imageZoom/alone/task",
            //         "get_thumb":"https://commonpreview.ys100.com/imageZoom/alone/zoom"
            //     },
            //     "is_thumb_model":"yes",
            //     "thumb_width_height_config":{
            //         "width":200,
            //         "height":200
            //     }
            // };
            
        },
        /**
         * 适配策略配置
         */
        adapter:{
            DesignW:375, //设计尺寸基准宽度 375
            winW:window.innerWidth,
            RemBase:16,
            getImgX:function () {
                var ImgX;
                ImgX = Math.ceil( window.devicePixelRatio*this.winW/this.DesignW );
                if(ImgX>3){//目前最大 只有3倍图
                    ImgX = 3;
                }
                if(ImgX<2){//目前最小 只有2倍图
                    ImgX = 2;
                }
                return ImgX;
            },
            /**
             * 获取本设备实际px值
             * @param {number} num 
             * @param {boolean} unit 
             */
            getDevPx:function(num,unit){
                return (num/this.DesignW*this.winW) + (unit ? 'px' : 0);
            },
            /**
             * 获取本设备实际rem值
             * @param {number} num 
             * @param {boolean} unit 
             */
            getDevRem:function(num,unit){
                return  (num/(this.winW / this.DesignW * this.RemBase)) + (unit ? 'rem' : 0);
            },
            /**
             * 正则匹配px或rem,并重新计算设备实际px或rem
             */
            autoTrans:function (value){
                var that = this;
                return value.replace(/([0-9.]+)(px|rem)/g,function (matchStr,numStr,unit) {
                    var num = parseFloat(numStr);
                    if(isNaN(num)){
                        console.error(numStr + ' is not a number!')
                    }
                    return unit === 'px' ? that.getDevPx(num,true) : that.getDevRem(num,true);
                });
            },
            /**
             * 设置设备基准rem
             */
            setBaseRem:function(){
                var fontSize = "";
                fontSize += ((this.winW / this.DesignW) * this.RemBase);
                fontSize += "px";
                document.querySelector("html").style.fontSize = fontSize;
            }

            
        },

        getClassifyType:function (type){
            var dict = {dir:"文件夹",video:"视频",document:"文档",image:"图片",music:"音乐",other:"其他",ysnote:"云笔记"}
            
            try {
                return dict[type];
            } catch (e) {
                return '';
            }
        },
        
		bitFormat:function(num,type){
			num = parseFloat(num);
			if(type == "KB"){
				num = 1024*num;
				}
			if(type == "MB"){
				num = 1024*1024*num;
			}
			if(type == "GB"){
				num = 1024*1024*1024*num;
			}
			if(type == "TB"){
				num = 1024*1024*1024*1024*num;
			}
			if(num < 1024){
				return num+"B";
			}
			if(num >= 1024 && num <1024*1024){
				return parseInt(num/1024)+"KB";
			}
			if(num >= 1024*1024 && num <1024*1024*1024){
				return parseInt(num/1024/1024)+"MB";
			}
			if(num >= 1024*1024*1024 && num <1024*1024*1024*1024){
				return parseInt(num/1024/1024/1024)+"GB";
			}
			return parseInt(num/1024/1024/1024/1024)+"TB";
		},
		getBitSize:function(num,type){
			num = parseFloat(num);
			if(type == "KB"){
				num = 1024*num;
				}
			if(type == "MB"){
				num = 1024*1024*num;
			}
			if(type == "GB"){
				num = 1024*1024*1024*num;
			}
			if(type == "TB"){
				num = 1024*1024*1024*1024*num;
			}
			return num;
        },
    };
    return Config;
});