/*
 * Shellv2 整合Shell容易误导人的逻辑
 * 薛原
 */

define(function () {
	var Shell = {
		IsAndroid: /android/i.test(navigator.userAgent),
		androidAccessNativeEvent: ["*"], //android所有事件由accessNative发送
		iosAccessNativeEvent: ['openWin', 'closeWin', 'checkNetProxy', 'InitPreview',"closeWinMulti","CallNativePreviewInit","transferList","CallNativePreview2Init",'CallNativePreview2InitForCoordination','showPreviewPage','newCoordinationPrev'], //ios有openWin|closeWin|checkNetProxy 这几个事件走accessNative发送
		/*
		 * 给原生壳发送事件
		 */
		"sendEvent": function (name, data, fn) {
			try {
				if (typeof (data) == "undefined") {
					data = {};
				}
				if (name == 'openWin') { //如果是新开窗口
					if (typeof (data.waitReadyEvent) == 'undefined') { //该属性表示要不要壳等ready事件，若为1表示需要等待，若为其他则表示不用等，默认是要等的
						data.waitReadyEvent = 1;
					}
					if (typeof (data.timeoutSec) == 'undefined') {
						data.timeoutSec = 30; //该属性表示打开该页面的超时时间，如果waitReadyEvent=1，则表示如果到超时还未等到ready事件
					}
				}
				if (this.isAndroid()) {
					if (this.androidAccessNativeEvent[0] == "*") {
						if (typeof fn === 'function') {
							api.accessNative({
								name: name,
								extra: data
							}, function (ret) {
								fn(ret);
							});
						} else {
							api.accessNative({
								name: name,
								extra: data
							});
						}

					} else if (this.androidAccessNativeEvent.indexOf(name) != -1) {
						if (typeof fn === 'function') {
							api.accessNative({
								name: name,
								extra: data
							}, function (ret) {
								fn(ret);
							});
						} else {
							api.accessNative({
								name: name,
								extra: data
							});
						}
					} else {
						api.sendEvent({
							name: name,
							extra: data
						}, typeof fn === 'function' ? fn : function (ret) {});
					}

				} else {
					if(name === 'messageUpdateData'){//发送消息推送事件，ios壳交互要转为json
						data =JSON.stringify(data)
					}
					if (this.iosAccessNativeEvent[0] == "*") {
						if (typeof fn === 'function') {
							api.accessNative({
								name: name,
								extra: data
							}, function (ret) {
								fn(ret);
							});
						} else {
							api.accessNative({
								name: name,
								extra: data
							});
						}
					} else if (this.iosAccessNativeEvent.indexOf(name) != -1) {
						if (typeof fn === 'function') {
							api.accessNative({
								name: name,
								extra: data
							}, function (ret) {
								fn(ret);
							});
						} else {
							api.accessNative({
								name: name,
								extra: data
							});
						}
					} else {
						api.sendEvent({
							name: name,
							extra: data
						});
					}
				}
			} catch (e) {
				console.warn(e);
			}
			console.log("sendEvent:" + name + "__" + JSON.stringify(data))
		},
		"sendPageReady": function (pageName) {
			if (this.isAndroid()) {
				if(pageName != undefined){
					this.sendEvent("page_ready",{"pageName":pageName});
				}else{
					this.sendEvent("page_ready");
				}
			} else {
				var url = window.location.href;
				if (url.indexOf("appweb") != -1) {
					url = url.split("?")[0];
					url = "/appweb/" + url.split("appweb/")[1];
					this.sendEvent("page_ready", {
						"url": url
					}); //ios的pageReady事件，携带url属性
				} else {
					if(pageName != undefined){
						this.sendEvent("page_ready",{"pageName":pageName});
					}else{
						this.sendEvent("page_ready");
					}
				}
			}
		},
		"isAndroid": function () {
			return /android/i.test(navigator.userAgent);
		},
		showProgress: function () {
			try {
				api.showProgress({
					title: "加载中...",
					text: "",
					animationType: "zoom",
					modal: true
				});
			} catch (e) {

			}
		},
		hideProgress: function () {
			try {
				api.hideProgress();
			} catch (e) {
			
			}
		},
		//高度过滤安全区域
		countHeightSafeArea:function(height,needFx){
			if(typeof(api) !="undefined"){
				if(api.safeArea.bottom){
					return height-api.safeArea.bottom + needFx;
				}else{
					return height + needFx;
				}
			}else{
				return height;
			}
		}
	}
	return Shell;
});