
/**
 * 弹窗基类
 * @example
 * $('#ele').PopupAlert({content:"Hello Alert!",title:'Warn',btnShow:['confirm'],btnText:['确定了','算了'],disableMaskClick:false});        //显示1个按钮：确定，遮罩可点击
 * $('#ele').PopupAlert({content:"Hello Alert!",title:'Warn',btnShow:['cancel'],btnText:['确定了','算了'],disableMaskClick:true});          //显示1个按钮：取消，遮罩不可点击
 * $('#ele').PopupAlert({content:"Hello Alert!",title:'Warn',btnShow:['confirm','cancel'],btnText:['确定了','算了'],disableMaskClick:true});//显示两个按钮，遮罩不可点击
 *
 * @example
$('body').PopupAlert({
    content:"",
    title:'这是一条警告信息！您需要确定一下哦！',
    btnShow:['confirm','cancel'],
    btnText:['确定了','算了'],
    disableMaskClick:true,
    confirm:function(){
        console.log('我点确定了')
    },
    cancel:function(){
        console.log('我点取消了')
    }
});
 * @options {{disableMaskClick:boolean}} disableMaskClick 关闭遮罩关闭功能，默认关闭遮罩可用
 * @event AlertBtn
 */
define(['SkinManager','Popup','Btn'],function(skinManager,require, exports){
	$.widget("ys.PopupAlert",$.ys.Popup,{
        _default:{
            title:'',
            content:'',
            btnShow:['confirm','cancel'],
            btnText:['确定','取消']
        },
        baseHeight:162,
		//默认参数
		//初始化，控件生命周期内只运行一次
		_init: function () {
            this._super();
            // $.extend(this.options,this._default);
            var _default = this.options;
            if(_default.btnShow.length<1||_default.btnText.length<1){
                throw new Error('"btnShow" , "btnText" 为数组，且长度必须大于1');
            }
            var tainHeight = _default.height?_default.height:this.baseHeight+"px";
            this._container = $("<div id='popup_container'></div>").style({"z-index":50001,"position":"absolute","top":"50%","left":"-148px","marginTop":"-"+tainHeight.replace("px","")/2+"px","marginLeft":"-148px","width":"296px","height":tainHeight,"background":"#fff","padding":"20px","borderRadius":"5px","transition":"top .3s ease,left .3s ease"});
            this._container.bind('click',function(e){
                e.preventDefault()
                e.stopPropagation();
                return false;
            });
            if(!_default.title && !_default.content){
                throw new Error('"title","content" 参数必须设置一个');
            }
            if(_default.title){
                this._title = $("<div></div>").style({"width":"256px","height":"24px","lineHeight":"24px","margin":"6px 0","fontSize":"16px","fontWeight":"bold","color":"#333","textAlign":"center","wordBreak":"break-all"});
                this._title.html(_default.title );
                this._container.append(this._title);
                if(!_default.content){
                    this._title.style({"marginTop":"20px"})
                }
            }

            this.contentHeight = _default.contentHeight ? _default.contentHeight : ($.transPx(tainHeight) - (this.baseHeight - 40 ))+'px';
            if(_default.content){
                this._content  = $('<div></div>').style({"width":"256px","maxHeight":'40px',"overflowY":"auto","wordBreak":"break-all","lineHeight":"20px","fontSize":"12px","fontWeight":"500","color":"#999999","textAlign":"center"});
                this._content.html(_default.content);
                this._container.append(this._content);
                this._content.style({"height":this.contentHeight,"maxHeight":this.contentHeight});
                if(!_default.title){
                    this._content.style({"marginTop":"20px"})
                }

            }


            var footer =  $('<div></div>').style({"position":"absolute","bottom":"25px","padding":"0 18px"});

            if(_default.btnShow.indexOf('cancel')>-1){

							  var leftBoradColor = skinManager.CheckColor('cloud_alert_left_backcolor',"#367bd6");
                this._cancel = $('<div>' +  _default.btnText[ _default.btnText.length>1 ? 1 : 0 ] + '</div>').Btn().style({"display":"inline-block","textAlign":"center","borderRadius":"20px","width":"100px","height":"36px","lineHeight":"38px","border":"1px solid "+leftBoradColor});
                this._cancel.style({"background":"#fff","color":skinManager.CheckColor('cloud_alert_left_textcolor',"#367bd6")});
                if(_default.btnShow.length===1){
                    this._cancel.style({"marginLeft":"69px"});
                }
                this._cancel.bind('BTN_CLICK',this,function(e){
                    if(typeof e.data.options.cancel === 'function'){
                        e.data.options.cancel();
                    }else{
                        e.data.element.trigger("AlertBtn",{type:'cancel'});
                    }
                    e.data.hidden('true');
                });
                footer.append(this._cancel);
            }
            if(_default.btnShow.indexOf('confirm')>-1){
							  var boradColor = skinManager.CheckColor('cloud_common_btn_color',"#367bd6");
                this._confirm = $('<div>' + _default.btnText[0] + '</div>').Btn().style({"display":"inline-block","textAlign":"center","borderRadius":"20px","width":"100px","height":"36px","lineHeight":"38px","border":"1px solid "+boradColor});
                this._confirm.style({"background":skinManager.CheckColor('cloud_common_btn_color',"#367bd6"),"color":"#fff"});
                if(_default.btnShow.length===1){
                    this._confirm.style({"marginLeft":"69px"});
                }
                this._confirm.bind('BTN_CLICK',this,function(e){
                    if(typeof e.data.options.confirm === 'function'){
                        e.data.options.confirm();
                    }else{
                        e.data.element.trigger("AlertBtn",{type:'confirm'});
                    }
                    e.data.hidden('true');
                });
                footer.append(this._confirm);
            }

            if(_default.btnShow.length>1){
                this._cancel.style({"marginRight":"20px"});
            }

            this._container.append(footer).appendTo(this._mask);
            if(typeof _default.hidden === 'undefined'){//默认显示
                _default.hidden = false;
            }
            this._container.hide();
            this.hidden(_default.hidden);
        },
        hidden:function(bool){
            if(bool){
                this._container.css({"left":"-50%"});
                this._container.hide();
                this.close();
            }else{
                this.open();
                this._container.show();
                setTimeout(function(self){
                    self._container.css({"left":"50%"});
                },1,this);
            }
        },
        /**设定确定回调 */
        setConfirm:function(call){
            if(typeof call !== 'function'){
                throw new Error('参数必须是函数');
            }
            this.option("confirm", call );
        },
        /**设定取消回调 */
        setCancel:function(call){
            if(typeof call !== 'function'){
                throw new Error('参数必须是函数');
            }
            this.option("cancel", call );
        },
        /**
         * 设置标题文字
         * @param {string} strTitle
         */
        setTitle:function(strTitle){
            if(!this._title){
                this._title = $("<div></div>").style({"width":"256px","height":"24px","lineHeight":"24px","margin":"6px 0","fontSize":"16px","fontWeight":"bold","color":"black","textAlign":"center","wordBreak":"break-all"});
                this._content.before(this._title);
                this._content.css({"marginTop":"0"})
            }
            this._title.html(strTitle);
        },
        /**
         * 设置内容文字
         * @param {string} strContent
         */
        setContent:function(strContent){
            if(!this._content){
                this._content  = $('<div></div>').style({"width":"256px","maxHeight":this.contentHeight,"overflowY":"auto","wordBreak":"break-all","lineHeight":"20px","fontSize":"12px","fontWeight":"500","color":"#999999","textAlign":"center"});
                this._title.after(this._content);
                this._title.css({"marginTop":"0"})
            }
            this._content.html(strContent);
        },

		//创建控件，控件生命周期内会运行多次
		_create: function () {

        },
		// 释放控件
		destroy: function () {
            $.Widget.prototype.destroy.call(this);
            if(this.element.length>0){
                this.element.remove();
            }
		}
	});
})
